@@ -65,7 +65,7 @@ def temp_dir(sub_dir='work'):
     """
     user = getpass.getuser().replace(' ', '_')
     current_date = date.today()
-    date_string = current_date.strftime("%d-%m-%Y")
+    date_string = current_date.isoformat()
     # Following 4 lines are a workaround for tempfile.tempdir() unreliabilty
     handle, filename = mkstemp()
     os.close(handle)
@@ -113,6 +113,9 @@ def unique_filename(**kwargs):
     if 'dir' not in kwargs:
         path = temp_dir('impacts')
         kwargs['dir'] = path
+    else:
+        path = temp_dir(kwargs['dir'])
+        kwargs['dir'] = path
     if not os.path.exists(kwargs['dir']):
         # Ensure that the dir mask won't conflict with the mode
         # Umask sets the new mask and returns the old
